Module params

Module params 

Some useful drawing parameters.

Constants

BLEND_FUNC_INVERT_COLOR
Writing white source pixels will invert the destination pixel. Color channels in the texture should all be equal to the alpha channel (grayscale) so that 100% opaque regions are white and 100% transparent regions are black.
BLEND_FUNC_NORMAL
The usual blending function to ensure that magnified texels are blended properly with transparency.