Draw3d

Struct Draw3d 

pub struct Draw3d {
    pub user_buffers: VecMap<VertexBuffer<Vert3dColor>>,
    pub user_draw: VecMap<UserDraw>,
    /* private fields */
}
3d drawing resources.

[                instance_vertices               ]

Fields

user_buffers: VecMap<VertexBuffer<Vert3dColor>>user_draw: VecMap<UserDraw>

Implementations

Source

impl Draw3d

pub fn new(glium_display: &Display<WindowSurface>) -> Self

pub fn draw(render: &Render<Default>, glium_frame: &mut Frame)

pub const fn instance_vertices( &self, ) -> &VertexBuffer<Vert3dOrientationScaleColor>

pub const fn instanced_aabb_lines(&self) -> &Range<u32>

pub fn set_instanced_aabb_lines(&mut self, range: Range<u32>)

pub const fn instanced_aabb_triangles(&self) -> &Range<u32>

pub fn set_instanced_aabb_triangles(&mut self, range: Range<u32>)

pub const fn instanced_meshes(&self) -> &VecMap<InstancedMesh>

pub fn set_instanced_mesh(&mut self, mesh_key: MeshKey, mesh: InstancedMesh)

pub fn rebuild_instanced_meshes( &mut self, glium_display: &Display<WindowSurface>, user_meshes: Vec<(MeshKey, Mesh, DrawPass)>, )

Re-builds instanced buffers to include given instanced meshes. The provided instanced mesh keys must not overlap with any of the built-in MeshIds.

pub fn instance_vertices_set( &mut self, glium_display: &Display<WindowSurface>, instances_init: InstancesInit<'_>, )

Creates a new vertex buffer holding per-instance 3D vertices for various instanced meshes (grid, hemisphere, sphere, cylinder, capsule), AABBs, and tile billboards, and sets the instanced ranges corresponding to each

pub fn instance_vertices_aabb_lines_write( &self, vertex_data: &[Vert3dOrientationScaleColor], )

pub fn instance_vertices_aabb_triangles_write( &self, vertex_data: &[Vert3dOrientationScaleColor], )

pub fn instance_vertices_billboard_write( &self, billboard_key: usize, vertex_data: &[Vert3dOrientationScaleColor], )

pub fn instance_vertices_mesh_write( &self, mesh_key: usize, vertex_data: &[Vert3dOrientationScaleColor], )

pub fn tile_billboard_create( &mut self, glium_display: &Display<WindowSurface>, tileset_texture: &Texture2d, billboard_key: usize, instances_range: Range<u32>, string: &str, )

Create a new instanced billboard by blitting a string of tiles to a new texture.

Panics if billboard texture with key already exists.