pub struct InstancedMesh {
pub line_indices_range: Range<u32>,
pub instances_range: Range<u32>,
pub shader_program_id: ProgramId,
pub draw_pass: DrawPass,
}Expand description
Wireframe meshes matched to ranges of per-instance vertices
Fields
line_indices_range: Range<u32>Slice of instanced_meshes.line_indices corresponding to this mesh: each
instance of the mesh will draw an instance of the vertices mapped to by
the range of indices
instances_range: Range<u32>Range of instance_vertices corresponding to this mesh: each of these
vertices will draw an instance of this mesh at that location
shader_program_id: ProgramIddraw_pass: DrawPassTrait Implementations
Sourceimpl Clone for InstancedMesh
impl Clone for InstancedMesh
Sourcefn clone(&self) -> InstancedMesh
fn clone(&self) -> InstancedMesh
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InstancedMesh
impl Debug for InstancedMesh
Sourceimpl PartialEq for InstancedMesh
impl PartialEq for InstancedMesh
Sourcefn eq(&self, other: &InstancedMesh) -> bool
fn eq(&self, other: &InstancedMesh) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for InstancedMesh
impl StructuralPartialEq for InstancedMesh