Module texture

Texture related utilities.

Enums

LoadError

Constants

CROSSHAIR_INVERSE_PNG_FILE_BYTES
For use with BLEND_FUNC_INVERT_COLOR– transparent pixels have black color values instead of white but the opaque portion is still white
CROSSHAIR_PNG_FILE_BYTES
An RGBA 16x16 square of pixels with white color values with an opaque cross of two pixels thickness
POINTER_HAND_PNG_FILE_BYTES_OFFSET
TILESET_EASCII_ACORN_8X8_INVERSE_PNG_FILE_BYTES
TILESET_EASCII_ACORN_8X8_PNG_FILE_BYTES
TILESET_EASCII_ACORN_16X16_INVERSE_PNG_FILE_BYTES
TILESET_EASCII_ACORN_16X16_PNG_FILE_BYTES

Functions

texture2d_with_mipmaps_from_bytes
Load a 2D texture from the given bytes with the given format and mipmaps.
texture2d_with_mipmaps_from_file
Load a 2D texture from the given path with the given format and mipmaps.
texture2darray_with_mipmaps_from_bytes
Load a 2D texture array from the given vector of byte slices for each individual texture, with the given format and mipmaps.
texture2darray_with_mipmaps_from_files
Load a 2D texture array from the given paths with the given format and mipmaps.