pub fn texture2darray_with_mipmaps_from_bytes(
glium_facade: &dyn Facade,
bytes_slices: &[&[u8]],
image_format: ImageFormat,
mipmaps: MipmapsOption,
) -> Result<Texture2dArray, LoadError>Expand description
Load a 2D texture array from the given vector of byte slices for each individual texture, with the given format and mipmaps.