pub struct Vert2dRectUvLayer {
pub bottom_left: [f32; 2],
pub dimensions: [f32; 2],
pub uv: [f32; 2],
pub layer: u16,
}Fields
bottom_left: [f32; 2]dimensions: [f32; 2]uv: [f32; 2]layer: u16Trait Implementations
Sourceimpl Clone for Vert2dRectUvLayer
impl Clone for Vert2dRectUvLayer
Sourcefn clone(&self) -> Vert2dRectUvLayer
fn clone(&self) -> Vert2dRectUvLayer
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Vert2dRectUvLayer
impl Debug for Vert2dRectUvLayer
Sourceimpl Default for Vert2dRectUvLayer
impl Default for Vert2dRectUvLayer
Sourcefn default() -> Vert2dRectUvLayer
fn default() -> Vert2dRectUvLayer
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for Vert2dRectUvLayer
impl PartialEq for Vert2dRectUvLayer
Sourcefn eq(&self, other: &Vert2dRectUvLayer) -> bool
fn eq(&self, other: &Vert2dRectUvLayer) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Vertex for Vert2dRectUvLayer
impl Vertex for Vert2dRectUvLayer
Sourcefn build_bindings() -> VertexFormat
fn build_bindings() -> VertexFormat
Builds the
VertexFormat representing the layout of this element.Sourcefn is_supported<C>(caps: &C) -> boolwhere
C: CapabilitiesSource + ?Sized,
fn is_supported<C>(caps: &C) -> boolwhere
C: CapabilitiesSource + ?Sized,
Returns true if the backend supports this vertex format.
impl Copy for Vert2dRectUvLayer
impl StructuralPartialEq for Vert2dRectUvLayer