pub struct Vert2dTileColor {
pub row: i32,
pub column: i32,
pub tile: u8,
pub fg: [f32; 4],
pub bg: [f32; 4],
}Fields
row: i32column: i32tile: u8fg: [f32; 4]bg: [f32; 4]Trait Implementations
Sourceimpl Clone for Vert2dTileColor
impl Clone for Vert2dTileColor
Sourcefn clone(&self) -> Vert2dTileColor
fn clone(&self) -> Vert2dTileColor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Vert2dTileColor
impl Debug for Vert2dTileColor
Sourceimpl Default for Vert2dTileColor
impl Default for Vert2dTileColor
Sourcefn default() -> Vert2dTileColor
fn default() -> Vert2dTileColor
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for Vert2dTileColor
impl PartialEq for Vert2dTileColor
Sourcefn eq(&self, other: &Vert2dTileColor) -> bool
fn eq(&self, other: &Vert2dTileColor) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Vertex for Vert2dTileColor
impl Vertex for Vert2dTileColor
Sourcefn build_bindings() -> VertexFormat
fn build_bindings() -> VertexFormat
Builds the
VertexFormat representing the layout of this element.Sourcefn is_supported<C>(caps: &C) -> boolwhere
C: CapabilitiesSource + ?Sized,
fn is_supported<C>(caps: &C) -> boolwhere
C: CapabilitiesSource + ?Sized,
Returns true if the backend supports this vertex format.
impl Copy for Vert2dTileColor
impl StructuralPartialEq for Vert2dTileColor