pub struct Lines3d {
pub vertices: Vec<Vert3dInstanced>,
pub indices: Vec<u32>,
}Expand description
Raw data defining a wireframe mesh
Fields
vertices: Vec<Vert3dInstanced>indices: Vec<u32>Implementations
Sourceimpl Lines3d
impl Lines3d
Sourcepub fn capsule(
index_offset: u32,
hemisphere_latitude_divisions: u16,
longitude_divisions: u16,
) -> Self
pub fn capsule( index_offset: u32, hemisphere_latitude_divisions: u16, longitude_divisions: u16, ) -> Self
Two hemispherical “caps” connected at their equators.
Intended to be scaled first and then each cap translated along the Z axis to achieve the correct capsule height.
Can also be used to render a hemisphere or a sphere by slicing the
corresponding number of indices. Note that the sphere is slightly
degenerate since there are duplicate vertices on the equator, and so the
last 2 * longitude_divisions indices will differ but the total index
count will be the same.
Panics
Panics of hemisphere_latitude_divisions is zero or if
longitude_divisions is less than two.
Sourceimpl Lines3d
impl Lines3d
Sourcepub fn hemisphere(
index_offset: u32,
latitude_divisions: u16,
longitude_divisions: u16,
) -> Self
pub fn hemisphere( index_offset: u32, latitude_divisions: u16, longitude_divisions: u16, ) -> Self
Generates a hemisphere with unit radius in the positive Z half-space
with a number of parallels equal to latitude_divisions and a number of
half-meridians equal to longitude_divisions