Support types for Glium rendering.
The Render struct holds all the context information and resources
required for making calls to OpenGL render commands (via glium).
Re-exports
Modules
- params
- Some useful drawing parameters.
- resource
- A trait for resource types with arbitrary
drawfunctionality and a default implementation that supports switching to a “quad viewport” mode. - viewport
- A rectangular viewport and associated 2D and 3D cameras.
Structs
- Render
- State for Glium-based rendering.
Functions
- frame_
fun_ default - Default frame function clears all and calls resource
draw_3dmethod followed bydraw_2dmethod. - frame_
fun_ default_ 2d - Default 2D frame function clears all and calls resource
draw_2dmethod. - frame_
fun_ default_ 3d - Default 3D frame function clears all and calls resource
draw_3dmethod.