Module resource

A trait for resource types with arbitrary draw functionality and a default implementation that supports switching to a “quad viewport” mode.

Re-exports

pub use self::draw2d::Draw2d;
pub use self::draw3d::Draw3d;

Modules

demodemo
draw2d
draw3d

Structs

Default
A default implementation of Resource containing the builtin shader programs and some pre-defined vertex sources.
DefaultTexture16IdIter
An iterator over the variants of DefaultTexture16Id
DefaultTexturePointerIdIter
An iterator over the variants of DefaultTexturePointerId
DefaultTilesetIdIter
An iterator over the variants of DefaultTilesetId

Enums

DefaultTexture16Id
DefaultTexturePointerId
DefaultTilesetId

Constants

LOWER_LEFT_VIEWPORT
LOWER_RIGHT_VIEWPORT
MAIN_VIEWPORT
OVERLAY_VIEWPORT
UPPER_LEFT_VIEWPORT
UPPER_RIGHT_VIEWPORT

Traits

Resource
Represents a generic Glium resource type for a renderer to use as a source of drawing (vertex rendering).

Type Aliases

PointerTextureIndexRepr