Struct Draw2d

pub struct Draw2d {
    pub rectangle_2d_vertices: VertexBuffer<Vert2dRectColor>,
    pub line_loop_vertices: VertexBuffer<Vert2d>,
    pub sprite_16x16_vertices: VertexBuffer<Vert2dLayer>,
    pub sprite_64x64_vertices: VertexBuffer<Vert2dLayer>,
    pub rectangle_16x16_vertices: VertexBuffer<Vert2dRectUvLayer>,
    pub rectangle_64x64_vertices: VertexBuffer<Vert2dRectUvLayer>,
    pub rectangle_anysize_vertices: VecMap<VertexBuffer<Vert2dRectUv>>,
    pub draw_pointer: Option<PointerTextureIndexRepr>,
    pub tile_2d_vertices: VertexBuffer<Vert2dTile>,
    pub tile_color_2d_vertices: VertexBuffer<Vert2dTileColor>,
    /* private fields */
}
2D drawing resources

Fields

rectangle_2d_vertices: VertexBuffer<Vert2dRectColor>

2D rectangle vertices with sub-ranges mapped to viewports by viewport_resources[i].draw_indices[j].rectangle.

line_loop_vertices: VertexBuffer<Vert2d>

Vertices to be rendered as line loops

sprite_16x16_vertices: VertexBuffer<Vert2dLayer>

Position and texture index of 2d sprites indexing the 16x16 texture array

sprite_64x64_vertices: VertexBuffer<Vert2dLayer>

Position and texture index of 2d sprites indexing the 64x64 texture array

rectangle_16x16_vertices: VertexBuffer<Vert2dRectUvLayer>

Position and texture index of 2d textured rectangles indexing the 16x16 texture array

rectangle_64x64_vertices: VertexBuffer<Vert2dRectUvLayer>

Position and texture index of 2d textured rectangles indexing the 64x64 texture array

rectangle_anysize_vertices: VecMap<VertexBuffer<Vert2dRectUv>>draw_pointer: Option<PointerTextureIndexRepr>

Draw the pointer vertex if the vertex has been set

tile_2d_vertices: VertexBuffer<Vert2dTile>

2D tile vertices with sub-ranges mapped to viewports by viewport_resources[i].draw_tiles[j].vertex_range.

tile_color_2d_vertices: VertexBuffer<Vert2dTileColor>

2D tile vertices with sub-ranges mapped to viewports by viewport_resources[i].draw_color_tiles[j].vertex_range.

Implementations

Source

impl Draw2d

pub fn new(glium_display: &Display<WindowSurface>) -> Self

pub fn draw(render: &Render<Default>, glium_frame: &mut Frame)

pub fn viewport_resources_get(&self, key: usize) -> Option<&ViewportResources>

pub fn viewport_resources_set( &mut self, key: usize, resources: ViewportResources, )

Set the viewport tile data for the specified viewport.

Panics if the tile data range is outside of the current tile vertices length.

pub fn line_loop_vertices_set( &mut self, glium_display: &Display<WindowSurface>, vertices: &[Vert2d], )