Viewport

Struct Viewport 

pub struct Viewport { /* private fields */ }
A viewport defined by a glium::Rect structure, with associated 2D and 3D cameras

Implementations

Source

impl Viewport

pub fn new(rect: Rect) -> Self

Create a new viewport with the given Rect

Panics

Width or height are zero:

let mut viewport = Viewport::new (glium::Rect {
  left: 0, bottom: 0, width: 0, height: 0
});

Width or height are greater than u16::MAX (65535):

let mut viewport = Viewport::new (glium::Rect {
  left: 0, bottom: 0, width: 65536, height: 65536
});
pub fn with_pose_3d(rect: Rect, pose: Pose3<f32>) -> Self

Also initializes self.camera3d with position and orientation

pub const fn rect(&self) -> &Rect

pub const fn camera2d(&self) -> Option<&Camera2d>

pub const fn camera3d(&self) -> Option<&Camera3d>

pub fn set_rect(&mut self, rect: Rect)

Should be called when screen resolution changes.

Panics

Width and height must be less than or equal to u16::MAX (65535):

viewport.set_rect (glium::Rect {
  left:   0,       bottom: 0,
  width:  100_000, height: 100_000 // panics
});

Width or height are zero:

viewport.set_rect (glium::Rect {
  left:   0, bottom: 0,
  width:  0, height: 0 // panics
});
pub fn camera2d_set_position(&mut self, position: Point2<f32>)

pub fn camera2d_set_zoom(&mut self, zoom: f32)

pub fn camera2d_move_local(&mut self, dx: f32, dy: f32)

pub fn camera2d_move_origin_to_bottom_left(&mut self)

pub fn camera3d_set_position(&mut self, position: Point3<f32>)

pub fn camera3d_set_orientation(&mut self, orientation: Rotation3<f32>)

pub fn camera3d_look_at(&mut self, target: Point3<f32>)

pub fn camera3d_move_local_xy(&mut self, dx: f32, dy: f32, dz: f32)

pub fn camera3d_rotate( &mut self, dyaw: Rad<f32>, dpitch: Rad<f32>, droll: Rad<f32>, )

pub fn camera3d_scale_fovy_or_zoom(&mut self, zoom: f32)

pub fn draw_parameters(&self) -> DrawParameters<'_>

Returns default glium draw parameters with the viewport set to the current rectangle

pub fn draw_parameters_blend_invert(&self) -> DrawParameters<'_>

Draw parameters that will result in ‘inverted’ colors (used by tile renderer)